@@ -5,8 +5,14 @@ module Data.Monoid.Compat (
 ) where
 
 import Data.Monoid as Base
+#if MIN_VERSION_base(4,9,0)
+  hiding ((<>))
+#endif
+#if MIN_VERSION_base(4,9,0)
+import Data.Semigroup ((<>))
+#endif
 
-#if !(MIN_VERSION_base(4,5,0))
+#if !(MIN_VERSION_base(4,5,0)) && !(MIN_VERSION_base(4,9,0))
 
 infixr 6 <>
 
